@@ -13,6 +13,7 @@ from .sessionrequired import SessionRequired
 from .subjectauthenticated import SubjectAuthenticated
 from .subjectclaimset import SubjectClaimSet
 from .subjectregistered import SubjectRegistered
+from .tokenconsumed import TokenConsumed
 
 
 __all__: list[str] = [
@@ -22,5 +23,6 @@ __all__: list[str] = [
     'SessionRequired',
     'SubjectAuthenticated',
     'SubjectClaimSet',
-    'SubjectRegistered'
+    'SubjectRegistered',
+    'TokenConsumed',
 ]
\ No newline at end of file
